==> galpy_1.8.0.orig.tar.gz: galpy-1.8.0/galpy/df/__init__.py <==
from . import diskdf
from . import surfaceSigmaProfile
from . import evolveddiskdf
from . import quasiisothermaldf
from . import streamdf
from . import streamgapdf
from . import jeans
from . import sphericaldf
from . import eddingtondf
from . import isotropicHernquistdf
from . import constantbetaHernquistdf
from . import osipkovmerrittHernquistdf
from . import kingdf
from . import isotropicPlummerdf
from . import isotropicNFWdf
from . import osipkovmerrittdf
from . import osipkovmerrittNFWdf
from . import constantbetadf
from . import streamspraydf
#
# Functions
#
impulse_deltav_plummer= streamgapdf.impulse_deltav_plummer
impulse_deltav_plummer_curvedstream= streamgapdf.impulse_deltav_plummer_curvedstream
impulse_deltav_hernquist= streamgapdf.impulse_deltav_hernquist
impulse_deltav_hernquist_curvedstream= streamgapdf.impulse_deltav_hernquist_curvedstream
impulse_deltav_general= streamgapdf.impulse_deltav_general
impulse_deltav_general_curvedstream= streamgapdf.impulse_deltav_general_curvedstream
impulse_deltav_general_orbitintegration= streamgapdf.impulse_deltav_general_orbitintegration
impulse_deltav_general_fullplummerintegration= streamgapdf.impulse_deltav_general_fullplummerintegration
impulse_deltav_plummerstream= streamgapdf.impulse_deltav_plummerstream
impulse_deltav_plummerstream_curvedstream= streamgapdf.impulse_deltav_plummerstream_curvedstream
#
# Classes
#
shudf= diskdf.shudf
dehnendf= diskdf.dehnendf
schwarzschilddf= diskdf.schwarzschilddf
DFcorrection= diskdf.DFcorrection
diskdf= diskdf.diskdf
evolveddiskdf= evolveddiskdf.evolveddiskdf
expSurfaceSigmaProfile= surfaceSigmaProfile.expSurfaceSigmaProfile
surfaceSigmaProfile= surfaceSigmaProfile.surfaceSigmaProfile
quasiisothermaldf= quasiisothermaldf.quasiisothermaldf
streamdf= streamdf.streamdf
streamgapdf= streamgapdf.streamgapdf
sphericaldf= sphericaldf.sphericaldf
eddingtondf= eddingtondf.eddingtondf
isotropicHernquistdf= isotropicHernquistdf.isotropicHernquistdf
constantbetaHernquistdf= constantbetaHernquistdf.constantbetaHernquistdf
osipkovmerrittHernquistdf= osipkovmerrittHernquistdf.osipkovmerrittHernquistdf
kingdf= kingdf.kingdf
isotropicPlummerdf= isotropicPlummerdf.isotropicPlummerdf
isotropicNFWdf= isotropicNFWdf.isotropicNFWdf
osipkovmerrittdf= osipkovmerrittdf.osipkovmerrittdf
osipkovmerrittNFWdf= osipkovmerrittNFWdf.osipkovmerrittNFWdf
constantbetadf= constantbetadf.constantbetadf
streamspraydf= streamspraydf.streamspraydf

==> galpy_1.8.1.orig.tar.gz: galpy-1.8.1/galpy/df/__init__.py <==
from . import (constantbetadf, constantbetaHernquistdf, diskdf, eddingtondf,
               evolveddiskdf, isotropicHernquistdf, isotropicNFWdf,
               isotropicPlummerdf, jeans, kingdf, osipkovmerrittdf,
               osipkovmerrittHernquistdf, osipkovmerrittNFWdf,
               quasiisothermaldf, sphericaldf, streamdf, streamgapdf,
               streamspraydf, surfaceSigmaProfile)

#
# Functions
#
impulse_deltav_plummer= streamgapdf.impulse_deltav_plummer
impulse_deltav_plummer_curvedstream= streamgapdf.impulse_deltav_plummer_curvedstream
impulse_deltav_hernquist= streamgapdf.impulse_deltav_hernquist
impulse_deltav_hernquist_curvedstream= streamgapdf.impulse_deltav_hernquist_curvedstream
impulse_deltav_general= streamgapdf.impulse_deltav_general
impulse_deltav_general_curvedstream= streamgapdf.impulse_deltav_general_curvedstream
impulse_deltav_general_orbitintegration= streamgapdf.impulse_deltav_general_orbitintegration
impulse_deltav_general_fullplummerintegration= streamgapdf.impulse_deltav_general_fullplummerintegration
impulse_deltav_plummerstream= streamgapdf.impulse_deltav_plummerstream
impulse_deltav_plummerstream_curvedstream= streamgapdf.impulse_deltav_plummerstream_curvedstream
#
# Classes
#
shudf= diskdf.shudf
dehnendf= diskdf.dehnendf
schwarzschilddf= diskdf.schwarzschilddf
DFcorrection= diskdf.DFcorrection
diskdf= diskdf.diskdf
evolveddiskdf= evolveddiskdf.evolveddiskdf
expSurfaceSigmaProfile= surfaceSigmaProfile.expSurfaceSigmaProfile
surfaceSigmaProfile= surfaceSigmaProfile.surfaceSigmaProfile
quasiisothermaldf= quasiisothermaldf.quasiisothermaldf
streamdf= streamdf.streamdf
streamgapdf= streamgapdf.streamgapdf
sphericaldf= sphericaldf.sphericaldf
eddingtondf= eddingtondf.eddingtondf
isotropicHernquistdf= isotropicHernquistdf.isotropicHernquistdf
constantbetaHernquistdf= constantbetaHernquistdf.constantbetaHernquistdf
osipkovmerrittHernquistdf= osipkovmerrittHernquistdf.osipkovmerrittHernquistdf
kingdf= kingdf.kingdf
isotropicPlummerdf= isotropicPlummerdf.isotropicPlummerdf
isotropicNFWdf= isotropicNFWdf.isotropicNFWdf
osipkovmerrittdf= osipkovmerrittdf.osipkovmerrittdf
osipkovmerrittNFWdf= osipkovmerrittNFWdf.osipkovmerrittNFWdf
constantbetadf= constantbetadf.constantbetadf
streamspraydf= streamspraydf.streamspraydf
